/*
 * This file is part of the Satimo Software Framework
 *
 * Copyright © Satimo 2015 All Rights Reserved, http://satimo.fr/
 */
namespace HardwareConfigurationGui.Views.MimoConfiguration
{
    using System.Windows;
    using System.Windows.Input;
    using Infragistics.Windows.DataPresenter;

    /// <summary>
    ///     Interaction logic for ScenarioConfiguration.xaml
    /// </summary>
    public partial class ConnectionConfiguration
    {
        private bool editingEnabled = false;

        public ConnectionConfiguration()
        {
            InitializeComponent();
        }

        void DataGrid_OnPreviewKeyDown(object sender, KeyEventArgs e)
        {
            if (e.Key == Key.Delete || e.Key == Key.Enter)
            {
                e.Handled = true;
            }
        }

        private void dataGrid_EditModeStarting(object sender, Infragistics.Windows.DataPresenter.Events.EditModeStartingEventArgs e)
        {
            // this will disable editing for the AddRecord cells when the "editingEnabled" flag is not enabled
            if (e.Cell.Record.IsAddRecord)
            {
                if (!editingEnabled)
                {
                    e.Cancel = true;
                }
            }
        }

        // add button handler
        private void ButtonAdd_Click(object sender, RoutedEventArgs e)
        {
            if (editingEnabled)
            {
                // add the record when in editing mode
                this.DataGrid.RecordManager.CommitAddRecord();
                editingEnabled = false;
            }
            else
            {
                // enter editing mode
                editingEnabled = true;
                this.DataGrid.ActiveCell = this.DataGrid.RecordManager.CurrentAddRecord.Cells[0];
                this.DataGrid.ExecuteCommand(DataPresenterCommands.StartEditMode);
            }
        }

        // delete button handler
        private void ButtonDelete_Click(object sender, RoutedEventArgs e)
        {
            editingEnabled = false;
            DataGrid.ActiveRecord.IsSelected = true;
            DataGrid.ExecuteCommand(DataPresenterCommands.DeleteSelectedDataRecords);
        }

        private void dataGrid_KeyUp(object sender, KeyEventArgs e)
        {
            // clear the "editingEnabled" flag when the Enter key is pressed
            if (editingEnabled && e.Key == Key.Enter)
            {
                editingEnabled = false;
            }
        }
    }
}